.. _api-label:

API
===

The generator module
--------------------

.. automodule:: psyclone.generator

.. autofunction:: generate

The parse module
----------------

.. automodule:: psyclone.parse.algorithm
 
.. autofunction:: parse

The transformations module
--------------------------

.. automodule:: psyclone.transformations
    :members:

The psyGen module
-----------------

.. automodule:: psyclone.psyGen

.. autoclass:: PSy
    :members:

The alg_gen module
------------------

.. automodule:: psyclone.alg_gen

.. autoclass:: Alg
    :members:

The line_length module
----------------------

.. automodule:: psyclone.line_length

.. autoclass:: FortLineLength
    :members:

